@@ -2,10 +2,10 @@
 /*
  * gsf-infile-msole.c :
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -137,7 +137,7 @@ ole_make_bat (MSOleBAT const *metabat, size_t size_guess, guint32 block,
 	GArray *bat = g_array_sized_new (FALSE, FALSE,
 		sizeof (guint32), size_guess);
 
-	guint8 *used = g_alloca (1 + metabat->num_blocks / 8);
+	guint8 *used = (guint8*)g_alloca (1 + metabat->num_blocks / 8);
 	memset (used, 0, 1 + metabat->num_blocks / 8);
 
 	if (block < metabat->num_blocks)
@@ -310,7 +310,7 @@ ole_dirent_new (GsfInfileMSOle *ole, guint32 entry, MSOleDirent *parent)
 	name_len = GSF_LE_GET_GUINT16 (data + DIRENT_NAME_LEN);
 	dirent->name = NULL;
 	if (0 < name_len && name_len <= DIRENT_MAX_NAME_SIZE) {
-		gunichar2 uni_name [DIRENT_MAX_NAME_SIZE];
+		gunichar2 uni_name [DIRENT_MAX_NAME_SIZE+1];
 		guint8 const *end;
 		int i;
 
@@ -323,6 +323,7 @@ ole_dirent_new (GsfInfileMSOle *ole, guint32 entry, MSOleDirent *parent)
 			/* be wary about endianness */
 			for (i = 0 ; i < name_len ; i += 2)
 				uni_name [i/2] = GSF_LE_GET_GUINT16 (data + i);
+			uni_name [i/2] = 0;
 
 			dirent->name = g_utf16_to_utf8 (uni_name, -1, NULL, NULL, NULL);
 		} else
@@ -371,7 +372,7 @@ ole_dirent_free (MSOleDirent *dirent)
 	g_free (dirent->collation_name);
 
 	for (tmp = dirent->children; tmp; tmp = tmp->next)
-		ole_dirent_free (tmp->data);
+		ole_dirent_free ((MSOleDirent *)tmp->data);
 	g_list_free (dirent->children);
 	g_free (dirent);
 }
@@ -504,7 +505,7 @@ ole_init_info (GsfInfileMSOle *ole, GError **err)
 		info->bb.bat.num_blocks = num_bat * (info->bb.size / BAT_INDEX_SIZE);
 		info->bb.bat.block	= g_new0 (guint32, info->bb.bat.num_blocks);
 
-		metabat = g_alloca (MAX (info->bb.size, OLE_HEADER_SIZE));
+		metabat = (guint32 *)g_alloca (MAX (info->bb.size, OLE_HEADER_SIZE));
 
 		/* Reading the elements invalidates this memory, make copy */
 		gsf_ole_get_guint32s (metabat, header + OLE_HEADER_START_BAT,
@@ -669,7 +670,7 @@ gsf_infile_msole_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 			if (ole->stream.buf != NULL)
 				g_free (ole->stream.buf);
 			ole->stream.buf_size = num_bytes;
-			ole->stream.buf = g_malloc (num_bytes);
+			ole->stream.buf = g_new (guint8, num_bytes);
 		}
 		buffer = ole->stream.buf;
 	}
@@ -748,7 +749,7 @@ gsf_infile_msole_new_child (GsfInfileMSOle *parent, MSOleDirent *dirent)
 		g_return_val_if_fail (sb_file != NULL, NULL);
 
 		child->stream.buf_size = info->threshold;
-		child->stream.buf = g_malloc (info->threshold);
+		child->stream.buf = g_new (guint8, info->threshold);
 
 		for (i = 0 ; i < child->bat.num_blocks; i++)
 			if (gsf_input_seek (GSF_INPUT (sb_file),
@@ -861,7 +862,7 @@ GSF_CLASS (GsfInfileMSOle, gsf_infile_msole,
  *
  * Returns : the new ole file handler
  **/
-GsfInfile *
+GsfInfileMSOle *
 gsf_infile_msole_new (GsfInput *source, GError **err)
 {
 	GsfInfileMSOle *ole;
@@ -878,5 +879,5 @@ gsf_infile_msole_new (GsfInput *source, GError **err)
 		return NULL;
 	}
 
-	return GSF_INFILE (ole);
+	return ole;
 }
