@@ -2,10 +2,10 @@
 /*
  * gsf-outfile.c :
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -36,7 +36,7 @@ GsfOutput *
 gsf_outfile_new_child (GsfOutfile *outfile,
 		       char const *name, gboolean is_dir)
 {
-	g_return_val_if_fail (outfile != NULL, FALSE);
+	g_return_val_if_fail (outfile != NULL, NULL);
 
 	return GET_CLASS (outfile)->new_child (outfile, name, is_dir);
 }
