@@ -2,10 +2,10 @@
 /*
  * gsf-zip-impl.h: 
  *
- * Copyright (C) 2002 Tambet Ingo (tambet@ximian.com)
+ * Copyright (C) 2002-2003 Tambet Ingo (tambet@ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -104,8 +104,8 @@ typedef struct {
 	guint32               crc32;
 	size_t                csize;
 	size_t                usize;
-	off_t                 offset;
-	off_t                 data_offset;
+	gsf_off_t                 offset;
+	gsf_off_t                 data_offset;
 	guint32               dostime;
 } ZipDirent;
 
